@@ -28,6 +28,6 @@ def industries(term, auth):
 
 def all(term, auth):
     big_list = []
-    big_list = loads(threat_activities(term, auth))["rows"] + loads(malware_analysis(term, auth))["rows"] + loads(threat_groups(term, auth))["rows"] + loads(collector(term, auth))["casefiles"] + loads(industries(term, auth))["rows"]
+    big_list = threat_activities(term, auth)["rows"] + malware_analysis(term, auth)["rows"] + threat_groups(term, auth)["rows"] + collector(term, auth)["casefiles"] + industries(term, auth)["rows"]
     return big_list
 
